@@ -15,7 +15,8 @@ relationship <- R6Class(
       doc <- read_xml( x = path )
       children <- xml_children( doc )
       ns <- xml_ns( doc )
-      private$id <- c( private$id, sapply( children, xml_attr, attr = "Id", ns) )
+
+      private$id <- c( private$id, sapply(children, xml_attr, attr = "Id", ns) )
       private$type <- c( private$type, sapply( children, xml_attr, attr = "Type", ns) )
       private$target <- c( private$target, sapply( children, xml_attr, attr = "Target", ns) )
       private$target_mode <- c( private$target_mode, sapply( children, xml_attr, attr = "TargetMode", ns) )
@@ -23,8 +24,8 @@ relationship <- R6Class(
       self
     },
     write = function(path) {
-
-      str <- paste0("<Relationship Id=\"", private$id,
+      if( length(private$id) )
+        str <- paste0("<Relationship Id=\"", private$id,
                     "\" Type=\"", private$type,
                     "\" Target=\"", private$target,
                     ifelse(
@@ -32,13 +33,15 @@ relationship <- R6Class(
                           "",
                           "\" TargetMode=\"External" ),
                     "\"/>", collapse = "")
+      else str <- ""
       str <- paste0("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>",
              "\n<Relationships  xmlns=\"http://schemas.openxmlformats.org/package/2006/relationships\">", str, "</Relationships>")
+      dir.create(dirname(path), showWarnings = FALSE, recursive = FALSE)
       cat(str, file = path)
       self
     },
     get_next_id = function(){
-      max(private$get_int_id()) + 1
+      max(c(0, private$get_int_id() ), na.rm = TRUE ) + 1
     },
     get_data = function() {
       data <- data.frame(id = private$id,
@@ -57,9 +60,17 @@ relationship <- R6Class(
       targets
     },
     add_img = function( src, root_target ) {
+
       src <- setdiff(src, private$ext_src)
       if( !length(src) ) return(self)
-      last_id <- max( private$get_int_id() )
+
+      if( any( grepl(" ", basename(src) ) ) ){
+        stop(paste(src, collapse = ", "),
+             ": images with blanks in their basenames are not supported, please rename the file(s).",
+             call. = FALSE)
+      }
+
+      last_id <- max( c(0, private$get_int_id() ), na.rm = TRUE )
 
       id <- paste0("rId", seq_along(src) + last_id)
       type <- rep("http://schemas.openxmlformats.org/officeDocument/2006/relationships/image",
@@ -74,6 +85,25 @@ relationship <- R6Class(
 
       self
     },
+    add_drawing = function( src, root_target ) {
+
+      src <- setdiff(src, private$ext_src)
+      if( !length(src) ) return(self)
+      last_id <- max( c(0, private$get_int_id()), na.rm = TRUE )
+
+      id <- paste0("rId", seq_along(src) + last_id)
+      type <- rep("http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing",
+                 length(src))
+      target <- file.path(root_target, basename(src) )
+
+      private$id <- c( private$id, id )
+      private$type <- c( private$type, type )
+      private$target <- c( private$target, target )
+      private$target_mode <- c( private$target_mode, rep(NA, length(id) ) )
+      private$ext_src <- c( private$ext_src, rep(NA, length(id) ) )
+
+      self
+    },
     add = function(id, type, target, target_mode = NA ) {
       private$id <- c( private$id, id )
       private$type <- c( private$type, type )
@@ -102,7 +132,9 @@ relationship <- R6Class(
     target_mode = NA,
     ext_src = NA,
     get_int_id = function(){
-      as.integer(gsub("rId([0-9]+)", "\\1", private$id))
+      if( length(private$id) > 0 )
+        as.integer(gsub("rId([0-9]+)", "\\1", private$id))
+      else integer(0)
     }
   )
 )
